@@ -1,4 +1,5 @@
 // Drive menu extension
+const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
 const Lang = imports.lang;
 const St = imports.gi.St;
@@ -91,7 +92,7 @@ DriveMenu.prototype = {
 
 // Put your extension initialization code here
 function init(metadata) {
-    imports.gettext.bindtextdomain('gnome-shell-extensions', metadata.localedir);
+    imports.gettext.bindtextdomain('gnome-shell-extensions', GLib.build_filenamev([metadata.path, 'locale']));
 }
 
 let _indicator;
