@@ -1,4 +1,5 @@
 // Sample extension code, makes clicking on the panel show a message
+const GLib = imports.gi.GLib;
 const St = imports.gi.St;
 const Mainloop = imports.mainloop;
 
@@ -19,7 +20,7 @@ function _showHello() {
 function init(metadata) {
     log ('Example extension initalized');
 
-    imports.gettext.bindtextdomain('gnome-shell-extensions', metadata.localedir);
+    imports.gettext.bindtextdomain('gnome-shell-extensions', GLib.build_filenamev([metadata.path, 'locale']));
 }
 
 let signalId;
@@ -38,4 +39,4 @@ function disable() {
 	Main.panel.actor.disconnect(signalId);
 	signalId = 0;
     }
-}
\ No newline at end of file
+}
